fnss.topologies.topology.rename_edge_attribute — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.topologies.topology.rename_edge_attribute

`rename_edge_attribute`(topology, old_attr, new_attr)

  Rename all edges attributes with a specific name to a new name

  Parameters: | topology : Topology The topology object old_attr : any hashable type Old attribute name new_attr : any hashable type New attribute name

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »